"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var ComponentRegistry = (function () {
    function ComponentRegistry(store, parent) {
        if (store === void 0) { store = {}; }
        if (parent === void 0) { parent = null; }
        this.store = store;
        this.parent = parent;
    }
    ComponentRegistry.prototype.get = function (componentName) {
        var _this = this;
        if (Array.isArray(componentName)) {
            var componentNames = componentName;
            var map_1 = {};
            componentNames.forEach(function (componentName) {
                map_1[componentName] = _this.getSingle(componentName);
            });
            return map_1;
        }
        return this.getSingle(componentName);
    };
    ComponentRegistry.prototype.getSingle = function (componentName) {
        if (this.store[componentName]) {
            return this.store[componentName];
        }
        var component;
        if (this.parent) {
            component = this.parent.getSingle(componentName);
        }
        return component;
    };
    ComponentRegistry.prototype.createElement = function (name) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var Component = this.get(name);
        if (!Component) {
            throw new Error("Sorry, but there is no component: \"" + name + "\" registered");
        }
        return react_1.default.createElement.apply(react_1.default, [Component].concat(args));
    };
    ComponentRegistry.prototype.blend = function (registry, options) {
        options = options || {};
        var store;
        if (registry instanceof ComponentRegistry) {
            store = registry.store;
        }
        else {
            store = Object.assign({}, registry);
        }
        if (options.prefix) {
            var newStore = {};
            for (var COMPONENT in store) {
                newStore[options.prefix + COMPONENT] = store[COMPONENT];
            }
            store = newStore;
        }
        if (options.throwOnCollisions) {
            for (var COMPONENT in store) {
                if (this.store[COMPONENT]) {
                    throw new Error("Sorry, we couldn't blend because there was a collision on: " + COMPONENT + " component");
                }
            }
        }
        Object.assign(this.store, store);
    };
    return ComponentRegistry;
}());
exports.ComponentRegistry = ComponentRegistry;
function createRegistry() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var registry = new (ComponentRegistry.bind.apply(ComponentRegistry, [void 0].concat(args)))();
    return new Proxy(registry, {
        get: function (obj, prop) {
            if (prop in obj) {
                return obj[prop];
            }
            else {
                return obj.getSingle(prop);
            }
        },
    });
}
exports.createRegistry = createRegistry;
exports.default = createRegistry();
//# sourceMappingURL=ComponentRegistry.js.map