"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var EventEmitter_1 = require("./EventEmitter");
var ComponentRegistry_1 = require("./ComponentRegistry");
var Molecule = (function () {
    function Molecule(value, parent) {
        this.name = 'anonymous';
        this.config = {};
        this.debug = false;
        this.agents = {};
        this.store = {};
        this.children = [];
        var config = value.config, agents = value.agents, store = value.store, registry = value.registry, name = value.name, debug = value.debug;
        if (parent) {
            this.parent = parent;
            parent.children.push(this);
        }
        this.emitter = new EventEmitter_1.default({
            context: name,
            debug: debug,
            parent: parent ? parent.emitter : null,
        });
        this.registry = ComponentRegistry_1.createRegistry({}, ComponentRegistry_1.default);
        if (value.registry) {
            this.registry.blend(value.registry, {});
        }
        if (value.agents) {
            this.storeAgents(value.agents);
        }
        if (value.name) {
            this.name = value.name;
        }
        if (value.store) {
            this.store = value.store;
        }
        if (config) {
            this.config = config;
        }
    }
    Object.defineProperty(Molecule.prototype, "root", {
        get: function () {
            if (!this.parent) {
                return this;
            }
            return this.parent.root;
        },
        enumerable: true,
        configurable: true
    });
    Molecule.prototype.init = function () {
        for (var agentName in this.agents) {
            var agent = this.agents[agentName];
            agent.prepare();
        }
        for (var agentName in this.agents) {
            var agent = this.agents[agentName];
            if (!agent.preventInit) {
                agent.init();
            }
        }
    };
    Molecule.prototype.clean = function () {
        var _this = this;
        if (this.parent) {
            this.parent.children = this.parent.children.filter(function (molecule) { return molecule !== _this; });
        }
        this.emitter.removeAllListeners();
        for (var agentName in this.agents) {
            var agent = this.agents[agentName];
            agent.emitter.removeAllListeners();
            agent.clean();
        }
    };
    Molecule.prototype.on = function (event, handler) {
        this.emitter.on(event, handler);
    };
    Molecule.prototype.off = function (event, handler) {
        this.emitter.off(event, handler);
    };
    Molecule.prototype.emit = function (event) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        (_a = this.emitter).emit.apply(_a, [event].concat(args));
        var _a;
    };
    Molecule.prototype.deepmit = function (event) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        this.emit.apply(this, [event].concat(args));
        this.children.forEach(function (child) {
            child.deepmit.apply(child, [event].concat(args));
        });
    };
    Molecule.prototype.closest = function (name) {
        if (this.name === name) {
            return this;
        }
        if (this.parent) {
            return this.parent.closest(name);
        }
        return null;
    };
    Molecule.prototype.getAgent = function (name) {
        var agent = this.agents[name];
        if (!agent) {
            throw new Error("We could not find the agent with name: \"" + name + "\" inside this molecule.");
        }
        return agent;
    };
    Molecule.prototype.storeAgents = function (_agents) {
        var agents = {};
        for (var agentName in _agents) {
            agents[agentName] = _agents[agentName](this);
        }
        this.agents = agents;
    };
    return Molecule;
}());
exports.default = Molecule;
//# sourceMappingURL=Molecule.js.map