"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ComponentRegistry_1 = require("./../ComponentRegistry");
var mocha_1 = require("mocha");
var chai_1 = require("chai");
mocha_1.describe('ComponentRegistry', function () {
    mocha_1.it('createRegistry()', function () {
        var registry = ComponentRegistry_1.createRegistry();
        chai_1.assert.isTrue(registry instanceof ComponentRegistry_1.ComponentRegistry);
    });
    mocha_1.it('Should work be able to store and fetch', function () {
        var dummy = function () { return null; };
        var registry = ComponentRegistry_1.createRegistry({
            Dummy1: dummy,
        });
        var Dummy1 = registry.Dummy1;
        chai_1.assert.equal(dummy, Dummy1);
    });
    mocha_1.it('Should work be able to blend properly', function () {
        var dummy = function () { return null; };
        var registry = ComponentRegistry_1.createRegistry({
            Dummy1: dummy,
        });
        registry.blend({
            Dummy2: dummy,
        });
        var Dummy2 = registry.Dummy2;
        chai_1.assert.equal(dummy, Dummy2);
    });
    mocha_1.it('Should work with parents on multiple levels', function () {
        var dummy = function () { return null; };
        var parent1 = ComponentRegistry_1.createRegistry({
            Dummy1: dummy,
        });
        var parent2 = ComponentRegistry_1.createRegistry({}, parent1);
        var child = ComponentRegistry_1.createRegistry({
            Dummy2: dummy,
        }, parent2);
        var Dummy2 = child.Dummy2;
        chai_1.assert.equal(dummy, Dummy2);
    });
    mocha_1.it('Should work with get properly', function () {
        var dummy = function () { return null; };
        var parent = ComponentRegistry_1.createRegistry({
            Dummy1: dummy,
        });
        chai_1.assert.equal(dummy, parent.get('Dummy1'));
        var Dummy1 = parent.get(['Dummy1']).Dummy1;
        chai_1.assert.equal(dummy, Dummy1);
    });
});
//# sourceMappingURL=ComponentRegistry.js.map