"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var ComponentRegistry_1 = require("./../ComponentRegistry");
var Molecule_1 = require("../Molecule");
var Agent_1 = require("../Agent");
var mocha_1 = require("mocha");
var chai_1 = require("chai");
mocha_1.describe('MoleculeModel', function () {
    mocha_1.it('Should instantiate properly', function () {
        var dummy = function () { return null; };
        var molecule = new Molecule_1.default({
            name: 'dummy',
            store: {
                value: 'dummy',
            },
            registry: {
                Dummy1: dummy,
            },
            config: {
                value: 'dummy-config',
            },
        });
        chai_1.assert.isTrue(molecule.registry instanceof ComponentRegistry_1.ComponentRegistry);
        chai_1.assert.equal('dummy', molecule.name);
        chai_1.assert.equal('dummy', molecule.store.value);
        chai_1.assert.equal(dummy, molecule.registry.get('Dummy1'));
        chai_1.assert.equal('dummy-config', molecule.config.value);
    });
    mocha_1.it('Should instantiate and clean agents properly', function (done) {
        var inInit = false;
        var inValidate = false;
        var inPrepare = false;
        var MyAgent = (function (_super) {
            __extends(MyAgent, _super);
            function MyAgent() {
                return _super !== null && _super.apply(this, arguments) || this;
            }
            MyAgent.prototype.validate = function (config) {
                inValidate = true;
            };
            MyAgent.prototype.prepare = function () {
                if (!inValidate) {
                    done('Should have been in-validate first');
                }
                inPrepare = true;
            };
            MyAgent.prototype.init = function () {
                if (!inPrepare) {
                    done('Should have been in-prepare first');
                }
                inInit = true;
            };
            MyAgent.prototype.clean = function () {
                chai_1.assert.isTrue(inValidate);
                chai_1.assert.isTrue(inInit);
                chai_1.assert.isTrue(inPrepare);
                done();
            };
            return MyAgent;
        }(Agent_1.default));
        var molecule = new Molecule_1.default({
            agents: {
                dummy: MyAgent.factory(),
            },
        });
        molecule.init();
        molecule.clean();
    });
    mocha_1.it('Should get the current agents and throw if not found', function (done) {
        var MyAgent = (function (_super) {
            __extends(MyAgent, _super);
            function MyAgent() {
                return _super !== null && _super.apply(this, arguments) || this;
            }
            return MyAgent;
        }(Agent_1.default));
        var molecule = new Molecule_1.default({
            agents: {
                dummy: MyAgent.factory(),
            },
        });
        chai_1.assert.isTrue(molecule.getAgent('dummy') instanceof MyAgent);
        try {
            molecule.getAgent('dummy-not-exists');
        }
        catch (e) {
            done();
        }
    });
    mocha_1.it('Should work as a tree with children, root and closest', function () {
        var root = new Molecule_1.default({
            name: 'i_am_root',
        });
        var parent = new Molecule_1.default({
            name: 'i_am_parent',
        }, root);
        var child = new Molecule_1.default({
            name: 'i_am_child',
        }, parent);
        chai_1.assert.isTrue(child.root === root);
        chai_1.assert.isTrue(root.root === root);
        chai_1.assert.isTrue(root.children.length === 1);
        chai_1.assert.isTrue(parent.children.length === 1);
        chai_1.assert.isTrue(child.children.length === 0);
        chai_1.assert.isTrue(child.closest('i_am_parent') === parent);
        chai_1.assert.isTrue(parent.closest('i_am_parent') === parent);
        chai_1.assert.isTrue(root.closest('i_am_parent') === null);
        var orphan = new Molecule_1.default({
            name: 'i_am_orphan',
        });
        chai_1.assert.isFalse(!!orphan.parent);
        child.clean();
        chai_1.assert.isTrue(parent.children.length === 0);
    });
    mocha_1.it('Should work with deep event propagation', function (done) {
        var root = new Molecule_1.default({
            name: 'i_am_root',
        });
        var parent = new Molecule_1.default({
            name: 'i_am_parent',
        }, root);
        var child = new Molecule_1.default({
            name: 'i_am_child',
        }, parent);
        child.on('deep', function () { return done(); });
        root.deepmit('deep');
    });
    mocha_1.it('Should work with deep and bottom-up event propagation', function (done) {
        var root = new Molecule_1.default({
            name: 'i_am_root',
        });
        var parent = new Molecule_1.default({
            name: 'i_am_parent',
        }, root);
        var child = new Molecule_1.default({
            name: 'i_am_child',
        }, parent);
        var inRoot = false;
        root.on('deep', function () { return (inRoot = true); });
        child.on('deep', function () {
            chai_1.assert.isTrue(inRoot);
            done();
        });
        root.deepmit('deep');
    });
});
//# sourceMappingURL=Molecule.js.map