"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
require("./enzyme.config");
var withs_1 = require("../withs");
var mole_1 = require("../mole");
var MoleculeWrap_1 = require("../MoleculeWrap");
var Molecule_1 = require("../Molecule");
var Agent_1 = require("../Agent");
var mocha_1 = require("mocha");
var chai_1 = require("chai");
var React = require("react");
var enzyme_1 = require("enzyme");
mocha_1.describe('withs', function () {
    mocha_1.it('mole', function () {
        function HelloDumb(_a) {
            var molecule = _a.molecule, value = _a.value;
            return (React.createElement("div", null, molecule instanceof Molecule_1.default && value == 123
                ? "Yes:" + molecule.config.text
                : 'No'));
        }
        var Dummy = mole_1.default(function () {
            return {
                config: {
                    text: 'Woop',
                },
            };
        })(HelloDumb);
        var wrapper = enzyme_1.shallow(React.createElement(Dummy, { value: 123 }));
        chai_1.assert.include(wrapper.html(), 'Yes:Woop');
    });
    mocha_1.it('withMolecule', function () {
        function HelloDumb(_a) {
            var molecule = _a.molecule, value = _a.value;
            return (React.createElement("div", null, value == 123 && molecule instanceof Molecule_1.default ? 'Yes' : 'No'));
        }
        var Hello = withs_1.withMolecule(HelloDumb);
        var Dummy = function () { return (React.createElement(MoleculeWrap_1.default, null,
            React.createElement("div", null,
                React.createElement(Hello, { value: 123 })))); };
        var wrapper = enzyme_1.shallow(React.createElement(Dummy, null));
        chai_1.assert.include(wrapper.html(), 'Yes');
    });
    mocha_1.it('<WithMolecule />', function () {
        function HelloDumb(_a) {
            var molecule = _a.molecule;
            return React.createElement("div", null, molecule instanceof Molecule_1.default ? 'Yes' : 'No');
        }
        var Dummy = function () { return (React.createElement(MoleculeWrap_1.default, null,
            React.createElement("div", null,
                React.createElement(withs_1.WithMolecule, null, function (molecule) { return React.createElement(HelloDumb, { molecule: molecule }); })))); };
        var wrapper = enzyme_1.shallow(React.createElement(Dummy, null));
        chai_1.assert.include(wrapper.html(), 'Yes');
    });
    mocha_1.it('withAgent', function () {
        function HelloDumb(_a) {
            var agent = _a.agent;
            return React.createElement("div", null, agent instanceof Agent_1.default ? 'Yes' : 'No');
        }
        var Hello = withs_1.withAgent('dummy')(HelloDumb);
        var MyAgent = (function (_super) {
            __extends(MyAgent, _super);
            function MyAgent() {
                return _super !== null && _super.apply(this, arguments) || this;
            }
            return MyAgent;
        }(Agent_1.default));
        var Dummy = function () { return (React.createElement(MoleculeWrap_1.default, { agents: { dummy: MyAgent.factory() } },
            React.createElement(Hello, null))); };
        var wrapper = enzyme_1.shallow(React.createElement(Dummy, null));
        chai_1.assert.include(wrapper.html(), 'Yes');
    });
    mocha_1.it('<WithAgent />', function () {
        function HelloDumb(_a) {
            var agent = _a.agent;
            return React.createElement("div", null, agent instanceof Agent_1.default ? 'Yes' : 'No');
        }
        var MyAgent = (function (_super) {
            __extends(MyAgent, _super);
            function MyAgent() {
                return _super !== null && _super.apply(this, arguments) || this;
            }
            return MyAgent;
        }(Agent_1.default));
        var Dummy = function () { return (React.createElement(MoleculeWrap_1.default, { agents: { dummy: MyAgent.factory() } },
            React.createElement(withs_1.WithAgent, { agent: "dummy" }, function (_a) {
                var agent = _a.agent, molecule = _a.molecule;
                return React.createElement(HelloDumb, { agent: agent });
            }))); };
        var wrapper = enzyme_1.shallow(React.createElement(Dummy, null));
        chai_1.assert.include(wrapper.html(), 'Yes');
    });
    mocha_1.it('Molecule should be able to have access to the parent molecule', function () {
        var Hello = function (_a) {
            var molecule = _a.molecule;
            var isOk = molecule.name === 'child' &&
                molecule.parent &&
                molecule.parent.name === 'parent';
            return React.createElement("div", null, isOk ? 'Yes' : 'No');
        };
        var Wrapper = function () { return (React.createElement(MoleculeWrap_1.default, { name: "parent" },
            React.createElement(MoleculeWrap_1.default, { name: "child" },
                React.createElement(Hello, null)))); };
        var wrapper = enzyme_1.shallow(React.createElement(Wrapper, null));
        chai_1.assert.include(wrapper.html(), 'Yes');
    });
    mocha_1.it('Molecule & parents -- should dispatch event to parent molecule', function (done) {
        var Hello = function (_a) {
            var molecule = _a.molecule;
            molecule.emit('propagate');
            return null;
        };
        function agent(molecule) {
            return {
                prepare: function () { },
                validate: function () { },
                clean: function () { },
                init: function () {
                    molecule.on('propagate', function () { return done(); });
                },
            };
        }
        var Wrapper = function () { return (React.createElement(MoleculeWrap_1.default, { name: "parent", agents: { agent: agent } },
            React.createElement(MoleculeWrap_1.default, { name: "child" },
                React.createElement(Hello, null)))); };
        var wrapper = enzyme_1.shallow(React.createElement(Wrapper, null));
        wrapper.html();
    });
});
//# sourceMappingURL=withs.js.map